#
# spec file for package xdg-desktop-portal-gtk
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdg-desktop-portal-gtk
Version:        1.14.1
Release:        3.1
Summary:        Backend implementation for xdg-desktop-portal using GTK+
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/flatpak/xdg-desktop-portal-gtk
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz

BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fontconfig)
# Needed for use of gtk apps outside of gnome
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.14
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(xdg-desktop-portal) >= 1.14
# Requires the xdg-desktop-portal service to be available
Requires:       xdg-desktop-portal
# Needed for use of gtk apps outside of gnome
Requires:       gsettings-desktop-schemas
# Users of GTK+ 3.0 and flatpak would enjoy this integration
Supplements:    (gtk3-schema and (flatpak or snapd))
# Users of GTK4 and flatpak would enjoy this integration
Supplements:    (gtk4-schema and (flatpak or snapd))
%if 0%{?suse_version} >= 1330
BuildRequires:  pkgconfig(gtk+-wayland-3.0) >= 3.21.5
%endif

%description
A backend implementation for xdg-desktop-portal that is using GTK+ and
various pieces of GNOME infrastructure, such as the org.gnome.Shell.Screenshot
or org.gnome.SessionManager D-Bus interfaces.

%lang_package

%prep
%autosetup -p1

%build
# All backends that are disabled are instead provided by
# xdg-desktop-portal-gnome, to keep this package free of GNOME dependencies.
%configure \
	--disable-silent-rules \
	--enable-appchooser \
	--disable-background \
	--disable-screencast \
	--disable-screenshot \
	--enable-settings \
	--disable-wallpaper \
	--disable-lockdown \
	%{nil}
%make_build

%install
%make_install
%find_lang %{name}

%post
%systemd_user_post %{name}.service

%preun
%systemd_user_preun %{name}.service

%files
%license COPYING
%{_libexecdir}/xdg-desktop-portal-gtk
%{_datadir}/dbus-1/services/org.freedesktop.impl.portal.desktop.gtk.service
%dir %{_datadir}/xdg-desktop-portal
%dir %{_datadir}/xdg-desktop-portal/portals
%{_datadir}/xdg-desktop-portal/portals/gtk.portal
%{_datadir}/applications/xdg-desktop-portal-gtk.desktop
%{_userunitdir}/xdg-desktop-portal-gtk.service

%files lang -f %{name}.lang

%changelog
* Fri Apr 21 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Pass missing --disable-lockdown to configure,
  xdg-desktop-portal-gnome handles that one too.
* Sat Apr  8 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Change Supplements: Replace gtk3 with gtk3-schema, ensure the
  supplements gets triggered.
- Add (gtk4-schema and (flatpak or snapd)) Supplements:
  Futureproof the supplements, as more and more of GNOME moves to
  gtk4.
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- Update to version 1.14.1:
  + printing,
  - wallpaper: Fix some memory leaks.
  - Consistently include .desktop in the fallback app name.
  + screencast: Fall back to desktop ID if we don't know the app
    name.
  + appchooser: Fix a use-after-free.
  + wallpaper: Handle errors storing images in the cache.
  + email: Fix a crash if no addresses are provided.
  + notification: Fix notifications for apps with no ID not
    appearing.
  + screenshot: Report whether PickColor is implemented, if
    possible.
* Sun Mar 27 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 1.14.0:
  + Add an implementation of the dynamic launcher portal
  + notification: Fix activation of default action with target
  + Updated translations.
* Mon Jan 17 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 1.12.0:
  + settings: Provide org.freedesktop.appearance.color-scheme key
  + settings: Handle org.gnome.desktop.a11y.interface schema
  + notification: Handle actions with targets properly
  + Enable settings and appchooser portals by default
  + Translation updates
* Fri Nov 12 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires and
  gsettings-desktop-schemas Requires and pass enable-appchooser and
  enable-settings to meson. This is needed for flatpak gtk apps
  running outside of gnome. See upstream issue/pull
  https://github.com/flatpak/xdg-desktop-portal-gtk/pull/362 and
  rh#2012315 for more info.
* Fri Sep 24 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Pass --disable-silent-rules, --disable-appchooser,
  - -disable-background, --disable-screencast, --disable-screenshot,
  - -disable-settings, and --disable-wallpaper to configure, make
  use of xdg-desktop-portal-gnome, and more importantly, remove all
  gnome-dependencies from this package.
- Following the above, drop pkgconfig(gio-2.0),
  pkgconfig(gio-unix-2.0) and pkgconfig(gnome-desktop-3.0)
  BuildRequires.
- Add explicit pkgconfig(fontconfig) BuildRequires.
- Add systemd_user_post and systemd_user_preun macros to post/preun
  sections.
* Sat Sep 18 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.10.0:
  + filechooser: Fix a focus issue
  + inhibit: Autostart org.gnome.ScreenSaver
  + screencast: Force window icon size
  + Make portal backends with GNOME dependencies optional and
    disable them by default. Use xdg-desktop-portal-gnome, or use
  - -enable-wallpaper to build with the wallpaper backend
  - -enable-screenshot to build with the screenshot backend
  - -enable-screencast to build with screencast/remoting backends
  - -enable-background to build with the background backend
  - -enable-settings to build with the settings backend
  - -enable-appchooser to build with the appchooser backend
  + Updated translations.
* Mon Jan  4 2021 Aria Buckles <aria@toole1.com>
- Update to version 1.8.0:
  + filechooser: Return the current filter
  + screenshot: Fix cancellation
  + appchooser: Avoid a crash
  + wallpaper:
  - Properly preview placement settings
  - Drop the lockscreen option
  + printing: Improve the notification
  + Updated translations.
- Changes from version 1.7.1:
  + filechooser:
  - Handle the "directory" option to select directories
  - Only show preview when we have an image
  + Updated translations.
- Changes from version 1.7.0:
  + screencast: Support mutter version 3
  + settings: Fall back to gsettings for enable-animations
  + Updated translations.
- Drop xdg-dpg-support-mutter-pipewire-3-api.patch: Fixed upstream.
* Mon Feb 24 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add xdg-dpg-support-mutter-pipewire-3-api.patch: screencast: Bump
  supported Mutter version to 3 (New pipewire api ver 3).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Fri Dec 20 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0:
  + Updated translations.
- Changes from version 1.5.2:
  + email: Work with sandboxed email clients.
  + wallpaper:
  - Support http: uris.
  - Improve preview.
  + appchooser: Modernize the appearance.
  + background: Improve application monitoring.
  + Require xdg-desktop-portal 1.5.
- Changes from version 1.5.1:
  + settings: Get animations-enabled setting from gnome-shell.
  + wallpaper: Add a portal backend for setting desktop backgrounds.
  + email: Support multiple addresses, cc and bcc.
  + filechooser: Support saving multiple files.
  + Updated translations.
- Changes from version 1.5.0:
  + screencast:
  - Support window selection.
  - Fix a crash.
  + settings:
  - Add a settings portal backend.
  - Handle enable-animations setting like gsd.
  + Updated translations.
- Add BuildRequires:  pkgconfig(gnome-desktop-3.0): New dependency.
* Thu Aug  8 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Supplement gtk3 in combination with flatpak or snapd instead of
  just supplementing against gnome-shell. Allows to the package to
  be auto-triggered for installation also on other desktops
  (boo#1136753).
* Thu Jun 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.4.0:
  + inhibit: Implement session state tracking.
  + screencast:
  - Allow selecting source types.
  - Support cursor modes.
  + Add a background & autostart portal.
  + Updated translations.
* Wed Jan 30 2019 bjorn.lie@gmail.com
- Update to version 1.2.0:
  + file chooser: Support setting current filter.
  + Updated translations.
- Changes from version 1.1.1:
  + lockdown: Implement the lockdown backend.
  + email: Be more careful when selecting a handler.
  + Updated translations.
- Changes from version 1.1.0:
  + Respect GNOME lockdown settings for printing, save-to-disk and
    app choosing.
  + filechooser: Set proper default accept label.
  + appchooser: Implement UpdateChoices and update the dialog.
  + Updated translations.
* Wed Dec 19 2018 bjorn.lie@gmail.com
- Update to version 1.0.2:
  + filechooser: Add returned files to recent files
  + inhibit: Implement screensaver monitoring
- Changes from version 1.0.1:
  + Use gvfs
  + Unset GTK_USE_PORTAL
  + Require xdg-desktop-portal 1.0
  + Updated translations.
- Changes from version 1.0:
  + screenshot: Add a PickColor method
  + screencast: Some UI improvements
  + Improve --help output
- Changes from version 0.99:
  + Shorten excessively long filenames in the app chooser dialog
  + Fixes for the screencast portal
  + Support more email clients in the Email portal
  + Fix a crash in the print portal
- Switch to tarball release, upstream now releases stable tarballs.
- Following the above, drop libtool BuildRequires and autogen.sh
  call.
* Tue Jun 26 2018 bjorn.lie@gmail.com
- Update to version 0.11:
  + screenshot:
  - Show dialog in the interactive case
  - Handle not getting requestor info
  + Add more warnings to the parent handling code
  + README.md: Doesn't actually require Flatpak
  + Add files via upload
  + Add print preview
  + remotedesktop:
  - Propagate supported device types
  - Pass along axis 'finish' flags
  + configure: Add gio-unix-2.0.pc dependency
  + Add correct msgid-bugs address to Makevars file
  + Updated translations.
- Add pkgconfig(gio-unix-2.0) BuildRequires: New dependency.
* Mon Mar  5 2018 fcrozat@suse.com
- Update to version 0.10:
  + Fix critical in file chooser.
  + Add options to screenshot portals.
  + Add screencast and remote portal implementations.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb  6 2018 dimstar@opensuse.org
- Update to version 0.9:
  + Improve the app picker ui.
  + Fix error reporting in the email portal.
  + Updated translations.
* Wed Jul  5 2017 adrien.plazas@suse.com
- Don't use BuildRequires gtk+-wayland-3.0 if the SUSE version is
  below 1330, which prevent any version other than Tumbleweed and
  the upcoming SLE 15 and Leap 15 to have this enabled.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.7:
  + appchooserdialog: Fix CSS loading.
  + Fix desktop file generation.
  + Do not dist generated file xdg-desktop-portal-gtk.desktop.in.
  + Clean and do not distribute generated source files.
  + .gitignore: Add many generated files.
  + .desktop: Tell users to not translate icon name.
  + notification: Fix ::handle-* return values.
  + notification: Fix 'icon' lookup.
  + notification: Use 'app-icon' instead of 'image-path' hint.
  + notification: Support raw data in 'image-data' hint.
  + Fix a bug in the app chooser.
  + Drop UI config.
  + Use a shorter name for apps.
  + Make the heading bigger.
  + Use the filename for the heading.
  + Fully implement the app picker mockup.
  + Update po files.
  + Updated translations.
- Changes from version 0.6:
  + Avoid gtk_label_set_xalign()
  + Avoid G_DECLARE_* macros
  + Avoid gtk_css_provider_load_from_resource()
  + Avoid gtk_entry_grab_focus_without_selecting()
  + Avoid gtk_search_entry_handle_event()
  + Avoid g_autoptr() with GtkPrint types
  + Avoid gtk_print_job_set_source_fd()
  + configure: Update GLib and GTK+ versions
  + appchooserrow: Remove gedit references from UI file
  + appchooserrow: Don't set NULL icons
  + Implement org.freedesktop.impl.portal.Email
  + Update for API changes
  + email: Support thunderbird
  + Add a systemd user unit corresponding to the session service
  + Force the icon size to be 48
  + notification: Add better debug and error messages
  + Encode po/Makevars in UTF-8
  + Some fixes for the filechooser preview
  + Set the program name to a fixed string
  + Redo the app chooser
  + Add an appchooser test
  + Add an empty state
  + Cosmetic changes
  + Make icons 64x64
  + Allow setting the default in testappchooser
  + app chooser: Focus the default choice initially
  + Install a desktop file
  + Fix POFILES
  + Updated translations.
* Sun Jan 22 2017 zaitor@opensuse.org
- Update to version 0.5:
  + build: Add appropriate inclusion paths.
  + Add a preview to the file chooser portal.
  + notification: Support 'non-exported' actions.
  + More work on notifications.
  + Add a simple account portal information.
  + Fix deps for resource generation.
  + AppChooser: Add Wayland transient parent support.
  + Screenshot: Add Wayland transient parent support.
  + Drop an unused include.
  + Print: Add Wayland transient parent support.
  + Account: Add Wayland transient parent support.
  + Access: Add Wayland transient parent support.
  + Revise the account portal ui.
  + Another revision of the account portal ui.
  + Tweak account portal ui one more time.
  + Adapt to API changes in the Account portal.
  + File chooser:
  - Fix the handling of choices.
  - Properly set writable.
  + Add some missing files to EXTRA_DIST.
  + Updated translations.
* Thu Nov  3 2016 dimstar@opensuse.org
- Initial package, version 0.3.
